"use client";
import React, { useState } from "react";
import LiftSlider from "@/components/modules/Boat/LeftSlider";
import Image from "next/image";
import { GoDotFill } from "react-icons/go";
import { Rating } from "@mui/material";
import { IoCheckmarkSharp } from "react-icons/io5";
import CalendarPopup from "@/components/CalendarPopup/CalendarPopup";
import Link from "next/link";
import Description from "@/components/Product_page/Description";
import Review from "@/components/Product_page/Review";
import {
  FaceBookIcon,
  InstaIcon,
  TwitterIcon,
  WhiteLinkdInIcon,
  WhiteTickTokIcon,
} from "@/components/Icons";

export default function BoatView({ data }) {
  console.log("boat data", data);
  const [previewMedia, setPreviewMedia] = useState(
    data.pictures?.images[0]?.url
  );
  const [showCalendarPopup, setShowCalendarPopup] = useState(false);
  const [openDiscription, setOpenDiscription] = useState(false);
  const [openReview, setOpenReview] = useState(false);
  const [openAdditional_info, setOpenAdditional_info] = useState(true);

  const [checkedItems, setCheckedItems] = useState({
    secureTransaction: false,
    propertyInsurance: false,
    contentInsurance: false,
  });

  const handleCheckboxChange = (event) => {
    const { name, checked } = event.target;
    setCheckedItems({
      ...checkedItems,
      [name]: checked,
    });
  };

  const handleOpenValues = (value) => {
    if (value === "Description") {
      setOpenAdditional_info(false);
      setOpenReview(false);
      setOpenDiscription(true);
    } else if (value === "Reviews") {
      setOpenDiscription(false);
      setOpenAdditional_info(false);
      setOpenReview(true);
    } else if (value === "Additional") {
      setOpenDiscription(false);
      setOpenReview(false);
      setOpenAdditional_info(true);
    }
  };

  const truncateTitle = (title) => {
    const words = title.split(" ");
    if (words.length > 3) {
      return words.slice(0, 3).join(" ") + "...";
    }
    return title;
  };

  const handleArrangeViewingClick = () => {
    setShowCalendarPopup(true);
  };

  const handleCloseCalendarPopup = () => {
    setShowCalendarPopup(false);
  };

  return (
    <div className="theme-container">
      <div className="sm:flex xl:flex-nowrap flex-wrap gap-6 lg:gap-12 pt-10 lg:pt-24 pb-5">
        <div className="flex items-stretch sm:flex-row flex-col gap-4">
          <div className="w-full sm:w-[160px] shrink-0">
            <LiftSlider
              setPreviewMedia={setPreviewMedia}
              images={data?.pictures?.images}
            />
          </div>
          <Image
            alt={previewMedia}
            quality={100}
            height={580}
            width={580}
            className="sm:w-[70%] lg:min-w-[580px] object-cover rounded-lg"
            src={previewMedia ? previewMedia : "/assets/images/room.jpg"}
          />
        </div>
        <div className="relative flex items-start flex-col justify-between mt-6 sm:mt-0">
          <h1 className="text-blue fs-40 capitalize truncate w-[90%] font-semibold mb-1">
            {truncateTitle(data.title)}
          </h1>
          <h2 className="text-sm text-black tracking-wide">
            Availability: In Stock
          </h2>
          <div className="flex mb-2">
            <span className="flex items-center">
              <Rating
                className="text-base"
                name="half-rating-read"
                defaultValue={2.5}
                precision={0.5}
                readOnly
              />
              <span className="text-gray-600 ml-3">4 Reviews</span>
            </span>
          </div>
          <p className="leading-relaxed text-black">{data.description}</p>
          <div className="mt-3">
            <h2 className="font-medium mb-2">Details</h2>
            <div className="flex flex-wrap items-center p-2 shadow rounded mb-2 gap-5">
              <span className="flex flex-row items-center text-sm">
                <GoDotFill className="flex mr-2 text-gold-800" /> Color:
              </span>
              <span className="flex flex-row items-center text-sm">
                <GoDotFill className="flex mr-2 text-gold-800" /> Place:
              </span>

              <span className="flex flex-row items-center text-sm">
                <GoDotFill className="flex mr-2 text-gold-800" /> Speed:
              </span>
            </div>
            <h2 className="text-3xl font-semibold py-8">
              $ {parseFloat(data.price).toFixed(2)}
            </h2>
          </div>
          <div className="flex gap-3 flex-wrap items-center mb-5">
            <button className="flex text-white justify-center btn-gradient border-0 py-2 px-2 flex-grow focus:outline-none text-sm font-medium rounded">
              Book The Asset
            </button>
            <button
              onClick={handleArrangeViewingClick}
              className="flex text-white justify-center btn-gradient border-0 py-2 px-2 flex-grow focus:outline-none text-sm font-medium rounded"
            >
              Arrange Viewing
            </button>
            <span className="bg-offwhite p-2 rounded-md cursor-pointer">
              <Image
                src="/icons/heart.svg"
                alt="Description of your image"
                width={10}
                height={10}
                quality={90}
                className="w-full"
              />
            </span>
            <span className="bg-offwhite p-2 rounded-md cursor-pointer">
              <Image
                src="/icons/email.svg"
                alt="Description of your image"
                width={10}
                height={10}
                quality={90}
                className="w-full"
              />
            </span>
          </div>
          <span className="font-medium text-lg mb-2 block">Ref: 12390876</span>
          <div className="flex gap-5 font-medium text-lg items-center">
            <span>Share:</span>
            <div className="flex gap-2">
              <Link href="#">
                <FaceBookIcon className="h-[16px] w-[16px]" />
              </Link>
              <Link href="#">
                <InstaIcon className="h-[16px] w-[16px]" />
              </Link>
              <Link href="#">
                <WhiteLinkdInIcon className="h-[16px] w-[16px]" />
              </Link>
              <Link href="#">
                <TwitterIcon className="h-[16px] w-[16px]" />
              </Link>
              <Link href="#">
                <WhiteTickTokIcon className="h-[16px] w-[16px]" />
              </Link>
            </div>
          </div>
        </div>
      </div>
      <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 gap-4 text-base justify-center shadow p-3 mb-8">
        <div className="flex  items-center space-x-3">
          <input
            type="checkbox"
            id="secureTransaction"
            name="secureTransaction"
            onChange={handleCheckboxChange}
            className="accent-gold-400"
          />
          <label htmlFor="secureTransaction">Secure My Transaction</label>
          <div className="w-6 h-6 group relative cursor-pointer">
            <Image
              src="/product/exclamation-mark.svg"
              alt="Description of your image"
              width={300}
              height={300}
              quality={90} // Adjust quality as needed
              className="w-full"
            />
            <div className="bg-white hidden group-hover:flex absolute top-5 w-[480px] -left-50 transform flex-col items-center justify-center rounded-l-3xl rounded-b-3xl p-5 rounded shadow-lg">
              <h1 className="text-gold-400 text-center font-medium text-xl">
                Secure My Transaction
              </h1>
              <p className="text-sm text-center text-gray-700 font-normal py-2">
                For a small fee, enhance the security of your transaction with
                our added protection feature, providing peace of mind throughout
                your purchase process
              </p>
            </div>
          </div>
        </div>
        <div className="flex items-center space-x-3">
          <input
            type="checkbox"
            id="propertyInsurance"
            name="propertyInsurance"
            checked={checkedItems.propertyInsurance}
            onChange={handleCheckboxChange}
            className="mr-2 accent-gold-400"
          />
          <label htmlFor="propertyInsurance">Property Insurance</label>
          <div className="w-6 h-6 group relative cursor-pointer">
            <Image
              src="/product/exclamation-mark.svg"
              alt="Description of your image"
              width={300}
              height={300}
              quality={90} // Adjust quality as needed
              className="w-full"
            />
            <div className="hidden group-hover:flex absolute top-5 w-[480px] -left-50 transform flex-col items-center justify-center rounded-l-3xl rounded-b-3xl bg-white p-5 rounded shadow-lg">
              <h1 className="text-gold-400 text-center font-medium text-xl">
                Property Insurance
              </h1>
              <p className="text-sm text-center text-gray-700 font-normal py-2">
                Safeguard your asset against unforeseen events or damage
                post-purchase, providing financial protection for your property.
              </p>
            </div>
          </div>
        </div>
        <div className="flex items-center space-x-3">
          <input
            type="checkbox"
            id="contentInsurance"
            name="contentInsurance"
            checked={checkedItems.contentInsurance}
            onChange={handleCheckboxChange}
            className="mr-2 accent-gold-400"
          />
          <label htmlFor="contentInsurance">Content Insurance</label>
          <div className="w-6 h-6 group relative cursor-pointer">
            <Image
              src="/product/exclamation-mark.svg"
              alt="Description of your image"
              width={300}
              height={300}
              quality={90} // Adjust quality as needed
              className="w-full"
            />
            <div className="hidden group-hover:flex absolute top-5 right-0 w-[480px] transform flex-col items-center justify-center rounded-l-3xl rounded-b-3xl bg-white p-5 rounded shadow-lg">
              <h1 className="text-gold-400 text-center font-medium text-xl">
                Content Insurance
              </h1>
              <p className="text-sm text-center text-gray-700 font-normal py-2">
                Protect the contents within your property, car, or boat against
                damage, theft, or loss.
              </p>
            </div>
          </div>
        </div>
      </div>
      <div className="shadow bg-white rounded-t-md">
        <div className="mb-2 shadow inline-block">
          <button
            className={`text-sm font-medium px-8 py-3 ${
              openDiscription === true ? "btn-gradient rounded" : ""
            }`}
            onClick={() => {
              handleOpenValues("Description");
            }}
          >
            DESCRIPTION
          </button>
          <button
            className={`text-sm font-medium px-8 py-3 ${
              openAdditional_info === true ? "btn-gradient rounded" : ""
            }`}
            onClick={() => {
              handleOpenValues("Additional");
            }}
          >
            ADDITIONAL INFORMATION
          </button>
          <button
            className={`text-sm font-medium px-8 py-3 ${
              openReview === true ? "btn-gradient rounded" : ""
            }`}
            onClick={() => {
              handleOpenValues("Reviews");
            }}
          >
            REVIEWS
          </button>
        </div>

        {openAdditional_info && (
          <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-4 gap-3 rounded-lg px-10 pb-8">
            {/* {data.facilities.map((item, columnIndex) => (
            <div key={columnIndex} className="col-span-1">
              <div className="text-base font-normal">
                <div className="flex flex-row flex-wrap items-center p-2 space-x-2">
                  <IoCheckmarkSharp className="mr-4" /> {item}
                </div>
              </div>
            </div>
          ))} */}
          </div>
        )}

        {openDiscription && (
          <div>
            <Description text={data.description} />
          </div>
        )}
        {openReview && (
          <div>
            <Review text={data.reviewText} />
          </div>
        )}
        {showCalendarPopup && (
          <CalendarPopup onClose={handleCloseCalendarPopup} />
        )}
      </div>
    </div>
  );
}
